@@ -3,20 +3,21 @@
 
 use std::cell::RefCell;
 use std::collections::{BTreeMap, HashMap, VecDeque};
+use std::convert::TryInto;
 
 use anyhow::anyhow;
 use cid::multihash::{Code, Multihash};
 use cid::Cid;
+use fvm_ipld_blockstore::MemoryBlockstore;
+use fvm_ipld_encoding::de::DeserializeOwned;
+use fvm_ipld_encoding::{Cbor, CborStore, RawBytes};
 use fvm_shared::actor::builtin::Type;
 use fvm_shared::address::{Address, Protocol};
-use fvm_shared::blockstore::{CborStore, MemoryBlockstore};
 use fvm_shared::clock::ChainEpoch;
 use fvm_shared::consensus::ConsensusFault;
 use fvm_shared::crypto::randomness::DomainSeparationTag;
 use fvm_shared::crypto::signature::Signature;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::de::DeserializeOwned;
-use fvm_shared::encoding::{blake2b_256, Cbor, RawBytes};
 use fvm_shared::error::ExitCode;
 use fvm_shared::piece::PieceInfo;
 use fvm_shared::randomness::Randomness;
@@ -27,7 +28,7 @@ use fvm_shared::version::NetworkVersion;
 use fvm_shared::{ActorID, MethodNum};
 
 use crate::runtime::{ActorCode, MessageInfo, Policy, Runtime, RuntimePolicy, Syscalls};
-use crate::{actor_error, ActorError};
+use crate::{actor_error, ActorError, SYS_FORBIDDEN, SYS_ILLEGAL_ACTOR};
 
 lazy_static! {
     pub static ref SYSTEM_ACTOR_CODE_ID: Cid = make_builtin(b"fil/test/system");
@@ -512,9 +513,13 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
             }
         }
         self.expectations.borrow_mut().expect_validate_caller_addr = None;
-        return Err(actor_error!(ErrForbidden;
+        return Err(ActorError::new(
+            SYS_FORBIDDEN,
+            format!(
                 "caller address {:?} forbidden, allowed: {:?}",
-                self.message().caller(), &addrs
+                self.message().caller(),
+                &addrs
+            ),
         ));
     }
     fn validate_immediate_caller_type<'a, I>(&mut self, types: I) -> Result<(), ActorError>
@@ -559,10 +564,13 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
 
         self.expectations.borrow_mut().expect_validate_caller_type = None;
 
-        Err(
-            actor_error!(ErrForbidden; "caller type {:?} forbidden, allowed: {:?}",
-                self.caller_type, types),
-        )
+        Err(ActorError::new(
+            SYS_FORBIDDEN,
+            format!(
+                "caller type {:?} forbidden, allowed: {:?}",
+                self.caller_type, types
+            ),
+        ))
     }
 
     fn current_balance(&self) -> TokenAmount {
@@ -605,7 +613,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
 
     fn create<C: Cbor>(&mut self, obj: &C) -> Result<(), ActorError> {
         if self.state.is_some() {
-            return Err(actor_error!(SysErrIllegalActor; "state already constructed"));
+            panic!("state shouldn't have been set")
         }
         self.state = Some(self.store.put_cbor(obj, Code::Blake2b256).unwrap());
         Ok(())
@@ -625,7 +633,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
         F: FnOnce(&mut C, &mut Self) -> Result<RT, ActorError>,
     {
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "nested transaction"));
+            panic!("recursive transaction")
         }
         let mut read_only = self.state()?;
         self.in_transaction = true;
@@ -648,7 +656,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
     ) -> Result<RawBytes, ActorError> {
         self.require_in_call();
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "side-effect within transaction"));
+            return Err(ActorError::new(
+                SYS_ILLEGAL_ACTOR,
+                "side-effect within transaction".into(),
+            ));
         }
 
         assert!(
@@ -674,7 +685,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
         {
             let mut balance = self.balance.borrow_mut();
             if value > *balance {
-                return Err(actor_error!(SysErrSenderStateInvalid;
+                return Err(actor_error!(SYS_SENDER_STATE_INVALID;
                         "cannot send value: {:?} exceeds balance: {:?}",
                         value, *balance
                 ));
@@ -683,7 +694,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
         }
 
         match expected_msg.exit_code {
-            ExitCode::Ok => Ok(expected_msg.send_return),
+            ExitCode::OK => Ok(expected_msg.send_return),
             x => Err(ActorError::new(x, "Expected message Fail".to_string())),
         }
     }
@@ -701,7 +712,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
     fn create_actor(&mut self, code_id: Cid, actor_id: ActorID) -> Result<(), ActorError> {
         self.require_in_call();
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "side-effect within transaction"));
+            return Err(ActorError::new(
+                SYS_ILLEGAL_ACTOR,
+                "side-effect within transaction".into(),
+            ));
         }
         let expect_create_actor = self
             .expectations
@@ -717,7 +731,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
     fn delete_actor(&mut self, addr: &Address) -> Result<(), ActorError> {
         self.require_in_call();
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "side-effect within transaction"));
+            return Err(ActorError::new(
+                SYS_ILLEGAL_ACTOR,
+                "side-effect within transaction".into(),
+            ));
         }
         let exp_act = self.expectations.borrow_mut().expect_delete_actor.take();
         if exp_act.is_none() {
@@ -807,7 +824,14 @@ impl Syscalls for MockRuntime {
     }
 
     fn hash_blake2b(&self, data: &[u8]) -> [u8; 32] {
-        blake2b_256(data)
+        blake2b_simd::Params::new()
+            .hash_length(32)
+            .to_state()
+            .update(data)
+            .finalize()
+            .as_bytes()
+            .try_into()
+            .expect("fixed array size")
     }
     fn compute_unsealed_sector_cid(
         &self,
@@ -820,22 +844,22 @@ impl Syscalls for MockRuntime {
             .expect_compute_unsealed_sector_cid
             .take()
             .ok_or_else(
-                || actor_error!(ErrIllegalState; "Unexpected syscall to ComputeUnsealedSectorCID"),
+                || actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to ComputeUnsealedSectorCID"),
             )?;
 
         if exp.reg != reg {
-            return Err(anyhow!(actor_error!(ErrIllegalState;
+            return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE;
                 "Unexpected compute_unsealed_sector_cid : reg mismatch"
             )));
         }
 
         if exp.pieces[..].eq(pieces) {
-            return Err(anyhow!(actor_error!(ErrIllegalState;
+            return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE;
                 "Unexpected compute_unsealed_sector_cid : pieces mismatch"
             )));
         }
 
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(
                 exp.exit_code,
                 "Expected Failure".to_string(),
@@ -849,14 +873,14 @@ impl Syscalls for MockRuntime {
             .borrow_mut()
             .expect_verify_seal
             .take()
-            .ok_or_else(|| actor_error!(ErrIllegalState; "Unexpected syscall to verify seal"))?;
+            .ok_or_else(|| actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to verify seal"))?;
 
         if exp.seal != *seal {
             return Err(anyhow!(
-                actor_error!(ErrIllegalState; "Unexpected seal verification"),
+                actor_error!(USR_ILLEGAL_STATE; "Unexpected seal verification"),
             ));
         }
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(
                 exp.exit_code,
                 "Expected Failure".to_string(),
@@ -870,14 +894,14 @@ impl Syscalls for MockRuntime {
             .borrow_mut()
             .expect_verify_post
             .take()
-            .ok_or_else(|| actor_error!(ErrIllegalState; "Unexpected syscall to verify PoSt"))?;
+            .ok_or_else(|| actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to verify PoSt"))?;
 
         if exp.post != *post {
             return Err(anyhow!(
-                actor_error!(ErrIllegalState; "Unexpected PoSt verification"),
+                actor_error!(USR_ILLEGAL_STATE; "Unexpected PoSt verification"),
             ));
         }
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(
                 exp.exit_code,
                 "Expected Failure".to_string(),
@@ -897,22 +921,26 @@ impl Syscalls for MockRuntime {
             .expect_verify_consensus_fault
             .take()
             .ok_or_else(
-                || actor_error!(ErrIllegalState; "Unexpected syscall to verify_consensus_fault"),
+                || actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to verify_consensus_fault"),
             )?;
         if exp.require_correct_input {
             if exp.block_header_1 != h1 {
-                return Err(anyhow!(actor_error!(ErrIllegalState; "Header 1 mismatch")));
+                return Err(anyhow!(
+                    actor_error!(USR_ILLEGAL_STATE; "Header 1 mismatch")
+                ));
             }
             if exp.block_header_2 != h2 {
-                return Err(anyhow!(actor_error!(ErrIllegalState; "Header 2 mismatch")));
+                return Err(anyhow!(
+                    actor_error!(USR_ILLEGAL_STATE; "Header 2 mismatch")
+                ));
             }
             if exp.block_header_extra != extra {
                 return Err(anyhow!(
-                    actor_error!(ErrIllegalState; "Header extra mismatch"),
+                    actor_error!(USR_ILLEGAL_STATE; "Header extra mismatch"),
                 ));
             }
         }
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(
                 exp.exit_code,
                 "Expected Failure".to_string(),
